==> indigitall_flutter_plugin-0.5.0.tar.gz: lib/push/models/Topic.dart <==
import 'dart:convert';

class Topic {
  /// String field name code
  static const String _JSON_CODE = "code";

  /// String field name name
  static const String _JSON_NAME = "name";

  /// String field name visible
  static const String _JSON_VISIBLE = "visible";

  /// String field name subscribed
  static const String _JSON_SUBSCRIBED = "subscribed";

  /// code of topic
  String? code;

  /// name of topic
  String? name;

  /// if is visible
  bool visible = false;

  /// if is subscribed
  bool subscribed = false;

  /// Constructor of [Topic]
  Topic(Map? map) {
    map?.forEach((key, value) {
      switch (key) {
        case _JSON_CODE:
          code = value.toString();
          break;
        case _JSON_NAME:
          name = value.toString();
          break;
        case _JSON_VISIBLE:
          visible = value.toString() == "true";
          break;
        case _JSON_SUBSCRIBED:
          subscribed = value.toString() == "true";
          break;
      }
    });
  }

  /// Get a list of [topic]
  static List<Topic> createArray(dynamic topics) {
    List<dynamic> list = topics;
    List<Topic> topicList = [];
    for (int i = 0; i < list.length; i++) {
      Topic? topic = new Topic(null);
      list[i].forEach((key, value) {
        if (key == _JSON_CODE) topic.code = value.toString();
        if (key == _JSON_NAME) topic.name = value.toString();
        if (key == _JSON_VISIBLE) topic.visible = value.toString() == "true";
        if (key == _JSON_SUBSCRIBED)
          topic.subscribed = value.toString() == "true";
      });
      topicList.add(topic);
    }
    return topicList;
  }

  /// Conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (code != null) map[_JSON_CODE] = code;
    if (name != null) map[_JSON_NAME] = name;
    map[_JSON_VISIBLE] = visible;
    map[_JSON_SUBSCRIBED] = subscribed;
    return map;
  }

  /// Conversion to [String]
  @override
  String toString() {
    return json.encode(toMap());
  }
}

==> indigitall_flutter_plugin-2.1.1.tar.gz: lib/push/models/Topic.dart <==
import 'dart:convert';

class Topic {
  /// String field name code
  static const String _JSON_CODE = "code";

  /// String field name name
  static const String _JSON_NAME = "name";

  /// String field name visible
  static const String _JSON_VISIBLE = "visible";

  /// String field name subscribed
  static const String _JSON_SUBSCRIBED = "subscribed";

  /// code of topic
  String? code;

  /// name of topic
  String? name;

  /// if is visible
  bool visible = false;

  /// if is subscribed
  bool subscribed = false;

  /// Constructor of [Topic]
  Topic(Map? map) {
    map?.forEach((key, value) {
      switch (key) {
        case _JSON_CODE:
          code = value.toString();
          break;
        case _JSON_NAME:
          name = value.toString();
          break;
        case _JSON_VISIBLE:
          visible = value.toString() == "true";
          break;
        case _JSON_SUBSCRIBED:
          subscribed = value.toString() == "true";
          break;
      }
    });
  }

  /// Get a list of [topic]
  static List<Topic> createArray(dynamic topics) {
    List<dynamic> list = topics as List<String>;
    List<Topic> topicList = [];
    for (int i = 0; i < list.length; i++) {
      Topic? topic = new Topic(null);
      list[i].forEach((key, value) {
        if (key == _JSON_CODE) topic.code = value.toString();
        if (key == _JSON_NAME) topic.name = value.toString();
        if (key == _JSON_VISIBLE) topic.visible = value.toString() == "true";
        if (key == _JSON_SUBSCRIBED)
          topic.subscribed = value.toString() == "true";
      });
      topicList.add(topic);
    }
    return topicList;
  }

  /// Conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (code != null) map[_JSON_CODE] = code;
    if (name != null) map[_JSON_NAME] = name;
    map[_JSON_VISIBLE] = visible;
    map[_JSON_SUBSCRIBED] = subscribed;
    return map;
  }

  /// Conversion to [String]
  @override
  String toString() {
    return json.encode(toMap());
  }
}
